@@ -6,7 +6,7 @@ use Module::Install::Base;
 
 use vars qw($VERSION @ISA);
 BEGIN {
-    $VERSION = '0.11';
+    $VERSION = '0.20';
     @ISA     = 'Module::Install::Base';
 }
 
@@ -24,16 +24,30 @@ sub use_testml_tap {
 sub use_testml {
     my $self = shift;
 
-    $self->include('TestML');
-    $self->include('TestML::Base');
-    $self->include('TestML::Document');
-    $self->include('TestML::Parser');
-    $self->include('TestML::Parser::Grammar');
-    $self->include('TestML::Runner');
-    $self->include('TestML::Runner::TAP');
-    $self->include('TestML::Standard');
     $self->include('Pegex::Grammar');
     $self->include('Pegex::Base');
+
+    $self->include('TestML');
+    $self->include('TestML::Base');
+    $self->include('TestML::Compiler');
+    $self->include('TestML::Grammar');
+    $self->include('TestML::Library::Debug');
+    $self->include('TestML::Library::Standard');
+    $self->include('TestML::Runtime');
+    $self->include('TestML::Runtime::TAP');
+}
+
+sub testml_setup {
+    my $self = shift;
+    return unless $self->is_admin;
+    my $config = shift;
+    die "setup_config requires a yaml file argument"
+        unless $config;
+    die "'$config' is not an existing file"
+        unless -f $config;
+    print "Updating testml files...\n";
+    require TestML::Setup;
+    TestML::Setup::testml_setup($config);
 }
 
 1;
